/**
 * Copyright (C) 2016-2017  Dušan Vejnovič  <vaadin@dussan.org>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.dussan.vaadin.dtabs.demo.ui;

import java.io.IOException;
import java.util.logging.Level;
import java.util.logging.Logger;

import javax.servlet.ServletContext;

import org.dussan.vaadin.dtabs.DTabs;

import com.vaadin.event.LayoutEvents.LayoutClickEvent;
import com.vaadin.event.LayoutEvents.LayoutClickListener;
import com.vaadin.server.Page;
import com.vaadin.server.VaadinServlet;
import com.vaadin.ui.Alignment;
import com.vaadin.ui.Label;
import com.vaadin.ui.VerticalLayout;

public class Header
    extends VerticalLayout
    implements LayoutClickListener
{

    private static final long serialVersionUID = -17550247392618511L;

    private boolean isAttached = false;

    public Header()
    {
        // Auto-generated constructor stub
    }

    private void init()
        throws IOException
    {
        setStyleName( "header" );
        setSizeUndefined();
        setWidth( 100, Unit.PERCENTAGE );
        addLayoutClickListener( this );

        Label title = new Label( "dTabs Demo Gallery" );
        title.setId( "title" );
        title.setSizeUndefined();
        addComponent( title );
        setComponentAlignment( title, Alignment.TOP_CENTER );

        ServletContext servletContext = VaadinServlet.getCurrent()
                                                     .getServletContext();
        Label version = new Label( "( dTabs Demo - " + ManifestReader.getVersion( servletContext ) + "  ,  "
            + "dTabs - " + DTabs.getVersion() + "-" + DTabs.getGitVersion() + " )" );
        version.setId( "version" );
        version.setSizeUndefined();
        addComponent( version );
        setComponentAlignment( version, Alignment.TOP_CENTER );
    }

    @Override
    public void attach()
    {
        super.attach();
        if ( !isAttached )
        {
            isAttached = true;
            try
            {
                init();
            }
            catch ( IOException e )
            {
                Logger.getLogger( Header.class.getName() )
                      .log( Level.WARNING, e.getLocalizedMessage() );
            }
        }
    }

    @Override
    public void detach()
    {
        super.detach();
        removeLayoutClickListener( this );
    }

    @Override
    public void layoutClick( LayoutClickEvent event )
    {
        Page.getCurrent()
            .setUriFragment( "" );
    }

}
